==> polymake-3.6-1-armv6h.pkg.tar.xz: usr/include/polymake/graph/incidence_matrix.h <==
/* Copyright (c) 1997-2019
   Ewgenij Gawrilow, Michael Joswig, and the polymake team
   Technische Universität Berlin, Germany
   https://polymake.org

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version: http://www.gnu.org/licenses/gpl.txt.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
--------------------------------------------------------------------------------
*/
#ifndef POLYMAKE_GRAPH_INCIDENCE_MATRIX_H
#define POLYMAKE_GRAPH_INCIDENCE_MATRIX_H

#include "polymake/client.h"
#include "polymake/SparseMatrix.h"
#include "polymake/Graph.h"

namespace polymake { namespace graph {

namespace {

template <typename TGraph>
SparseMatrix<int> incidence_matrix_impl(const GenericGraph<TGraph>& G, int s=1)
{
   SparseMatrix<int> E (G.top().nodes(), G.top().edges());
   int col(0);
   for (auto eit = entire(edges(G.top())); !eit.at_end(); ++eit, ++col) {
      E(eit.from_node(), col) = s;
      E(eit.to_node(), col) = 1;
   }
   return E;
}

} // end anonymous namespace

template <typename TGraph>
SparseMatrix<int> incidence_matrix(const GenericGraph<TGraph>& p)
{
   return incidence_matrix_impl(p.top(), 1);
}

template<typename TGraph>
SparseMatrix<int> signed_incidence_matrix(const GenericGraph<TGraph>& p)
{
   return incidence_matrix_impl(p.top(), -1);
}

template<typename Dir>
SparseMatrix<int> incidence_matrix(perl::Object p)
{
   Graph<Dir> G=p.give("ADJACENCY");
   return incidence_matrix_impl(G, 1);
}

template<typename Dir>
SparseMatrix<int> signed_incidence_matrix(perl::Object p)
{
   Graph<Dir> G=p.give("ADJACENCY");
   return incidence_matrix_impl(G, -1);
}

} }

#endif

// Local Variables:
// mode:C++
// c-basic-offset:3
// indent-tabs-mode:nil
// End:

==> polymake-4.0-1-armv6h.pkg.tar.xz: usr/include/polymake/graph/incidence_matrix.h <==
/* Copyright (c) 1997-2020
   Ewgenij Gawrilow, Michael Joswig, and the polymake team
   Technische Universität Berlin, Germany
   https://polymake.org

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version: http://www.gnu.org/licenses/gpl.txt.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
--------------------------------------------------------------------------------
*/

#ifndef POLYMAKE_GRAPH_INCIDENCE_MATRIX_H
#define POLYMAKE_GRAPH_INCIDENCE_MATRIX_H

#include "polymake/client.h"
#include "polymake/SparseMatrix.h"
#include "polymake/Graph.h"

namespace polymake { namespace graph {

namespace {

template <typename TGraph>
SparseMatrix<Int> incidence_matrix_impl(const GenericGraph<TGraph>& G, Int s = 1)
{
   SparseMatrix<Int> E(G.top().nodes(), G.top().edges());
   Int col = 0;
   for (auto eit = entire(edges(G.top())); !eit.at_end(); ++eit, ++col) {
      E(eit.from_node(), col) = s;
      E(eit.to_node(), col) = 1;
   }
   return E;
}

} // end anonymous namespace

template <typename TGraph>
SparseMatrix<Int> incidence_matrix(const GenericGraph<TGraph>& p)
{
   return incidence_matrix_impl(p.top(), 1);
}

template<typename TGraph>
SparseMatrix<Int> signed_incidence_matrix(const GenericGraph<TGraph>& p)
{
   return incidence_matrix_impl(p.top(), -1);
}

template<typename Dir>
SparseMatrix<Int> incidence_matrix(BigObject p)
{
   Graph<Dir> G = p.give("ADJACENCY");
   return incidence_matrix_impl(G, 1);
}

template<typename Dir>
SparseMatrix<Int> signed_incidence_matrix(BigObject p)
{
   Graph<Dir> G=p.give("ADJACENCY");
   return incidence_matrix_impl(G, -1);
}

} }

#endif

// Local Variables:
// mode:C++
// c-basic-offset:3
// indent-tabs-mode:nil
// End:
